
API Reference
=============

.. autoclass:: korona.html.tags.A
    :members:


.. autoclass:: korona.html.tags.Abbr
    :members:


.. autoclass:: korona.html.tags.Acronym
    :members:


.. autoclass:: korona.html.tags.Address
    :members:


.. autoclass:: korona.html.tags.Area
    :members:


.. autoclass:: korona.html.tags.Article
    :members:


.. autoclass:: korona.html.tags.B
    :members:


.. autoclass:: korona.html.tags.Base
    :members:


.. autoclass:: korona.html.tags.Button
    :members:


.. autoclass:: korona.html.tags.Canvas
    :members:


.. autoclass:: korona.html.tags.Caption
    :members:


.. autoclass:: korona.html.tags.Cite
    :members:


.. autoclass:: korona.html.tags.Col
    :members:


.. autoclass:: korona.html.tags.ColGroup
    :members:


.. autoclass:: korona.html.tags.DD
    :members:


.. autoclass:: korona.html.tags.Del
    :members:


.. autoclass:: korona.html.tags.Details
    :members:


.. autoclass:: korona.html.tags.Dialog
    :members:


.. autoclass:: korona.html.tags.Div
    :members:


.. autoclass:: korona.html.tags.DL
    :members:


.. autoclass:: korona.html.tags.DT
    :members:


.. autoclass:: korona.html.tags.Embed
    :members:


.. autoclass:: korona.html.tags.FieldSet
    :members:


.. autoclass:: korona.html.tags.Figure
    :members:


.. autoclass:: korona.html.tags.Footer
    :members:


.. autoclass:: korona.html.tags.Form
    :members:


.. autoclass:: korona.html.tags.Frame
    :members:


.. autoclass:: korona.html.tags.FrameSet
    :members:


.. autoclass:: korona.html.tags.H1
    :members:


.. autoclass:: korona.html.tags.H2
    :members:


.. autoclass:: korona.html.tags.H3
    :members:


.. autoclass:: korona.html.tags.H4
    :members:


.. autoclass:: korona.html.tags.H5
    :members:


.. autoclass:: korona.html.tags.H6
    :members:


.. autoclass:: korona.html.tags.Head
    :members:


.. autoclass:: korona.html.tags.Header
    :members:


.. autoclass:: korona.html.tags.HR
    :members:


.. autoclass:: korona.html.tags.Html
    :members:


.. autoclass:: korona.html.tags.I
    :members:


.. autoclass:: korona.html.tags.IFrame
    :members:


.. autoclass:: korona.html.tags.Img
    :members:


.. autoclass:: korona.html.tags.Input
    :members:

